// AUTO-GENERATED BY UpdateGenVersion.bat a89f8d621c9c18f356b5354eed6af5fe17d5f016
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "a89f8d621c9c18f356b5354eed6af5fe17d5f016";
